==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-cpuload/cpuload_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <source>Cpu load %1%</source>
        <translation type="vanished">Carga do cpu %1%</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuload.cpp" line="124"/>
        <source>CPU load %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <source>LXQt Cpu Load settings</source>
        <translation type="vanished">Definições da Carga do cpu</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Mostrar texto</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Intervalo:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>seg.</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Orientação da barra:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Bottom up</source>
        <translation>De baixo para cima</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Top down</source>
        <translation>De cima para baixo</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="72"/>
        <source>Left to right</source>
        <translation>Da esquerda para a direita</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="73"/>
        <source>Right to left</source>
        <translation>Da direita para a esquerda</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-cpuload/cpuload_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <source>Cpu load %1%</source>
        <translation type="vanished">Carga do cpu %1%</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuload.cpp" line="125"/>
        <source>CPU load %1%</source>
        <translation>Carga do CPU %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <source>LXQt Cpu Load settings</source>
        <translation type="vanished">Definições da Carga do cpu</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Definições do CPU</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Mostrar texto</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Intervalo de atualização:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>seg</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Orientação da barra:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Largura da barra:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>Baixo -&gt; Cima</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>Cima -&gt; Baixo</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>Esquerda -&gt; Direita</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>Direita -&gt; Esquerda</translation>
    </message>
</context>
</TS>
